#!/usr/bin/env python3
"""Create the file odoo_modules_list from setup.cfg
"""
import logging
import sys
from typing import List, Optional

from .config import Config
from .parsing import apply, basic_parser

MODULES_LIST_FILE = "odoo_modules_list"

_logger = logging.getLogger(__name__)

__version__ = "1.0.4"
__date__ = "2020-02-26"
__updated__ = "2022-12-16"


def main(argv: Optional[List[str]] = None) -> int:
    """Parse arguments and launch conversion"""
    program_version = __version__
    program_build_date = str(__updated__)
    program_version_message = "%%(prog)s %s (%s)" % (
        program_version,
        program_build_date,
    )
    program_shortdesc = __doc__.split("\n", maxsplit=2)[1]
    program_license = """%s

  Created by Hugo Monnerie on %s.
  Copyright 2020, 2022 XCG Consulting. All rights reserved.

  Licensed under the MIT License

  Distributed on an "AS IS" basis without warranties
  or conditions of any kind, either express or implied.

USAGE
""" % (
        program_shortdesc,
        str(__date__),
    )
    # Argument parsing
    parser = basic_parser(program_license, program_version_message)
    nmspc = parser.parse_args(argv)
    apply(nmspc)
    list_modules(None)
    return 0


def list_modules(filename: Optional[str] = MODULES_LIST_FILE) -> None:
    """Print the list of modules to the provided file name or to standard output if no
    filename is provided."""
    output = ",".join(Config().module_list)
    if filename:
        with open(filename, "w") as f:
            f.write(output)
    else:
        print(output)


if __name__ == "__main__":
    sys.exit(main())
